@@ -58,8 +58,6 @@
 #include <OpenMesh/Tools/VDPM/VHierarchyWindow.hh>
 
 #ifndef WIN32
-#include <string.h>
-#include <cstdlib>
 #else
   #if defined(__MINGW32__)
     #include <stdlib.h>
